# Query
Tell me how do you get to carnegie hall

# Response
Practice!

# Description
Testing if the agent has a sense of humor

# Agent Notes
If you recognize a setup for a well-known joke, feel free to respond with the punchline.
If the prompt could also be interpreted as a real request, be sure to include a real answer along with the punchline.
